==> lc-lightbox-lite-1.3.0.tgz: package/README.md <==
# LC Lightbox (LITE)
LC Lightbox is a modern jQuery lightbox focused on contents.<br/> 
Totally responsive and adaptive, is extremely flexible to be tailored in the minimum details!

Hassle-free and immediate setup using an unique javascript file. <br/>
Overall plugin weight is only 42KB (JS) + 31KB (CSS)

![lc-lightbox](https://lcweb.it/wp-content/uploads/2018/10/lcl_github_img_2.png)


&nbsp;


Main features
---

* Elements Slideshow (manually or automatically initialized)
* Thumbnails Navigation (with customizable sizes and optional data-type icon)
* Effective Socials Share (with WhatsApp option on mobile)
* Element Contents (title, description and author)
* Images "right-click" protection
* Natively supports webp/avif images

* Fullscreen mode
	* Covering only browser or entire screen space
	* Optionally forced under target screen sizes
	* Fullscreen-only mode
	* Image option to cover available space (cropping it) or to be completely shown

* Elements direct download (not requiring PHP scripts)
* Components Toggling (thumbnails and texts).
* Thumbnails and texts optionally hidden by default under target screen sizes
* Dynamic Elements Tracking
* HTML support in element descriptions
* 100% CSS Driven
* (optional) Mousewheel and Keyboard elements navigation
* Swipe integration to navigate (requires AlloyFinger)
* Dev-oriented and well-documented [methods & Events](https://lcweb.it/lc-lightbox/documentation?section=methods)
* 4 layouts (text over element, under element or on right/left side)
* (optional) closing button on corner position <em>(for inner commands)</em>
* (optional) navigation buttons on middle position <em>(for inner commands)</em>
* Automatic fallback on text over image on small screens or whether element becomes too small
* 3 preset skins to be used and mixed on a single page (light, dark and minimal)
* Code projected to be easily skinned via CSS
* Dual commands position (inside and outside lightbox window)

* Element-based outer command forcing
* Elements complete preload once page is loaded
* Adapts to your page's code (you set how lightbox fetches contents from binded elements)
* Full control on each animation/effect timing
* Modal mode
* Thumbnails script support (eg. easily integrates with Timthumb)
* MUCH MORE! [check lightbox options](https://lcweb.it/lc-lightbox/documentation?section=opts)


&nbsp;


Requirements
---

* Any modern browser (IE 10+)
* jQuery v1.7+
* To implement touch actions you need to use [AlloyFinger](https://github.com/AlloyTeam/AlloyFinger/) (file included in LIB folder)


&nbsp;


Live Demo
---
[https://lcweb.it/lc-lightbox](https://lcweb.it/lc-lightbox)


&nbsp;


Documentation
---
[https://lcweb.it/lc-lightbox/documentation](https://lcweb.it/lc-lightbox/documentation)

Optionally you can install the plugin via Bower, using this instruction: `bower install lc-lightbox-lite`

&nbsp;


License
---

LC Lightbox LITE is free and released under the MIT license.<br/>
You can purchase the fully-featured premium version on [Codecanyon](https://codecanyon.net/user/lcweb/portfolio)
 

&nbsp;


Extra
---

Premium LC Lightbox version is implemented in the premium WordPress plugin [Global Gallery](http://www.lcweb.it/global-gallery)


&nbsp;


Fun Fact
---

Why release starts from v1.1? LC Lightbox has been used and developed for [Global Gallery](http://www.lcweb.it/global-gallery) WordPress plugin in 2017!

* * *

Copyright &copy; Luca Montanari (aka LCweb)

==> lc-lightbox-lite-1.3.2.tgz: package/README.md <==
# LC Lightbox (LITE)
LC Lightbox is a modern jQuery lightbox focused on contents.<br/> 
Totally responsive and adaptive, is extremely flexible to be tailored in the minimum details!

Hassle-free and immediate setup using an unique javascript file. <br/>
Overall plugin weight is only 46KB (JS) + 34KB (CSS)

![lc-lightbox](https://static.lcweb.it/lc-lightbox-lite/lcl_github_img.png)


&nbsp;


Main features
---

* Elements Slideshow (manually or automatically initialized)
* Thumbnails Navigation (with customizable sizes and optional data-type icon)
* Effective Socials Share (with WhatsApp option on mobile)
* Element Contents (title, description and author)
* Images "right-click" protection

* Fullscreen mode
	* Covering only browser or entire screen space
	* Optionally forced under target screen sizes
	* Fullscreen-only mode
	* Image option to cover available space (cropping it) or to be completely shown

* Elements direct download (not requiring PHP scripts)
* Components Toggling (thumbnails and texts).
* Thumbnails and texts optionally hidden by default under target screen sizes
* Dynamic Elements Tracking
* HTML support in element descriptions
* 100% CSS Driven
* (optional) Mousewheel and Keyboard elements navigation
* Swipe integration to navigate (requires AlloyFinger)
* Dev-oriented and well-documented [methods & Events](https://lcweb.it/lc-lightbox-jquery-plugin/documentation/?section=methods)
* 4 layouts (text over element, under element or on right/left side)
* (optional) closing button on corner position <em>(for inner commands)</em>
* (optional) navigation buttons on middle position <em>(for inner commands)</em>
* Automatic fallback on text over image on small screens or whether element becomes too small
* 3 preset skins to be used and mixed on a single page (light, dark and minimal)
* Code projected to be easily skinned via CSS
* Dual commands position (inside and outside lightbox window)

* Element-based outer command forcing
* Elements complete preload once page is loaded
* Adapts to your page's code (you set how lightbox fetches contents from binded elements)
* Full control on each animation/effect timing
* Modal mode
* Thumbnails script support (eg. easily integrates with Timthumb)
* MUCH MORE! [check lightbox options](https://lcweb.it/lc-lightbox-jquery-plugin/documentation/?section=opts)


&nbsp;


Requirements
---

* Any modern browser (IE 11+)
* jQuery v1.7+
* To implement touch actions you need to use [AlloyFinger](https://github.com/AlloyTeam/AlloyFinger/) (file included in LIB folder)


&nbsp;


Live Demo
---
[https://lcweb.it/lc-lightbox-jquery-plugin/](https://lcweb.it/lc-lightbox-jquery-plugin/)


&nbsp;


Documentation
---
[https://lcweb.it/lc-lightbox-jquery-plugin/documentation/](https://lcweb.it/lc-lightbox-jquery-plugin/documentation/)

Optionally you can install the plugin via Bower, using this instruction: `bower install lc-lightbox-lite`

&nbsp;


License
---

LC Lightbox LITE is free and released under the MIT license.<br/>
You can purchase the fully-featured premium version on the [LCweb Shop](https://lcweb.it/lc-lightbox-jquery-plugin/)
 

&nbsp;


Extra
---

Premium LC Lightbox version is implemented in the premium WordPress plugin [Global Gallery](https://lcweb.it/global-gallery-wordpress-photogallery-plugin/)


&nbsp;


Fun Fact
---

Why release starts from v1.1? LC Lightbox has been used and developed for [Global Gallery](https://lcweb.it/global-gallery-wordpress-photogallery-plugin/) WordPress plugin in 2017!

* * *

Copyright &copy; Luca Montanari (LCweb)
